Class: RunApi::Suno::Types::AlignedWord
- Inherits:
-
Core::BaseModel
- Object
- Core::BaseModel
- RunApi::Suno::Types::AlignedWord
- Defined in:
- lib/runapi/suno/types.rb
Overview
Word-level timing alignment for a single word in a track.
Word-level timing alignment for a single word in a track.